==> tw-server-5.0.15-20240705.083522-1-sources.jar: com/elitesland/tw/tw5/server/common/change/entity/ComChangeDO.java <==
package com.elitesland.tw.tw5.server.common.change.entity;


import com.elitescloud.boot.model.entity.BaseModel;
import com.elitescloud.cloudt.common.annotation.Comment;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;
import org.hibernate.annotations.Where;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Index;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 通用变更信息表(com_change)实体类
 *
 * @author carl
 */

@Entity
@Table(name = "com_change", indexes = {
        @Index(name = "type_index", columnList = "change_type"),
        @Index(name = "doc_id_index", columnList = "change_doc_id"),
        @Index(name = "version_no_index", columnList = "version_no")
})
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
@org.hibernate.annotations.Table(appliesTo = "com_change", comment = "通用变更信息表")
@Getter
@Setter
@Where(clause = "delete_flag= 0")
public class ComChangeDO extends
        BaseModel implements Serializable {
    private static final long serialVersionUID = 1L;

    @Column(name = "change_type")
    @Comment("变更类型")
    private String changeType;

    @Column(columnDefinition = "text")
    @Comment("变更信息")
    private String changeContent;

    @Column(name = "change_doc_id")
    @Comment("变更单据id")
    private String changeDocId;

    @Column(name = "version_no")
    @Comment("版本号")
    private Integer versionNo;

    @Column()
    @Comment("变更状态")
    private String changeStatus;

    /**
     * 流程状态
     */
    @Comment("流程状态")
    @Column()
    private String apprStatus;

    /**
     * 流程实例ID
     */
    @Comment("流程实例ID")
    @Column()
    private String apprProcInstId;

    private String extString1;
    private String extString2;
    private String extString3;
    private String extString4;
    private String extString5;
}

==> tw-server-5.1.56-20240823.091738-1-sources.jar: com/elitesland/tw/tw5/server/common/change/entity/ComChangeDO.java <==
package com.elitesland.tw.tw5.server.common.change.entity;


import com.elitescloud.boot.model.entity.BaseModel;
import com.elitescloud.cloudt.common.annotation.Comment;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;
import org.hibernate.annotations.Where;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Index;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 通用变更信息表(com_change)实体类
 *
 * @author carl
 */

@Entity
@Table(name = "com_change", indexes = {
        @Index(name = "type_index", columnList = "change_type"),
        @Index(name = "doc_id_index", columnList = "change_doc_id"),
        @Index(name = "version_no_index", columnList = "version_no")
})
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
@org.hibernate.annotations.Table(appliesTo = "com_change", comment = "通用变更信息表")
@Getter
@Setter
@Where(clause = "delete_flag= 0")
public class ComChangeDO extends
        BaseModel implements Serializable {
    private static final long serialVersionUID = 1L;

    @Column(name = "change_type")
    @Comment("变更类型")
    private String changeType;

    @Column(columnDefinition = "text")
    @Comment("变更信息")
    private String changeContent;

    @Column(name = "change_doc_id")
    @Comment("变更单据id")
    private String changeDocId;

    @Column(name = "version_no")
    @Comment("版本号")
    private Integer versionNo;

    @Column()
    @Comment("变更状态")
    private String changeStatus;

    /**
     * 流程状态
     */
    @Comment("流程状态")
    @Column()
    private String apprStatus;

    /**
     * 流程实例ID
     */
    @Comment("流程实例ID")
    @Column()
    private String procInstId;

    private String extString1;
    private String extString2;
    private String extString3;
    private String extString4;
    private String extString5;
}
